==> huaweicloudsdkmeeting-3.1.125-py2.py3-none-any.whl: huaweicloudsdkmeeting/v1/model/rest_set_interpreter_group_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RestSetInterpreterGroupBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'interpreter_groups': 'list[InterpreterGroupInfo]'
    }

    attribute_map = {
        'interpreter_groups': 'interpreterGroups'
    }

    def __init__(self, interpreter_groups=None):
        """RestSetInterpreterGroupBody

        The model defined in huaweicloud sdk

        :param interpreter_groups: 传译组列表信息
        :type interpreter_groups: list[:class:`huaweicloudsdkmeeting.v1.InterpreterGroupInfo`]
        """
        
        

        self._interpreter_groups = None
        self.discriminator = None

        self.interpreter_groups = interpreter_groups

    @property
    def interpreter_groups(self):
        """Gets the interpreter_groups of this RestSetInterpreterGroupBody.

        传译组列表信息

        :return: The interpreter_groups of this RestSetInterpreterGroupBody.
        :rtype: list[:class:`huaweicloudsdkmeeting.v1.InterpreterGroupInfo`]
        """
        return self._interpreter_groups

    @interpreter_groups.setter
    def interpreter_groups(self, interpreter_groups):
        """Sets the interpreter_groups of this RestSetInterpreterGroupBody.

        传译组列表信息

        :param interpreter_groups: The interpreter_groups of this RestSetInterpreterGroupBody.
        :type interpreter_groups: list[:class:`huaweicloudsdkmeeting.v1.InterpreterGroupInfo`]
        """
        self._interpreter_groups = interpreter_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RestSetInterpreterGroupBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmeeting-3.1.144-py2.py3-none-any.whl: huaweicloudsdkmeeting/v1/model/rest_set_interpreter_group_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RestSetInterpreterGroupBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'interpreter_groups': 'list[InterpreterGroupInfo]'
    }

    attribute_map = {
        'interpreter_groups': 'interpreterGroups'
    }

    def __init__(self, interpreter_groups=None):
        r"""RestSetInterpreterGroupBody

        The model defined in huaweicloud sdk

        :param interpreter_groups: 传译组列表信息
        :type interpreter_groups: list[:class:`huaweicloudsdkmeeting.v1.InterpreterGroupInfo`]
        """
        
        

        self._interpreter_groups = None
        self.discriminator = None

        self.interpreter_groups = interpreter_groups

    @property
    def interpreter_groups(self):
        r"""Gets the interpreter_groups of this RestSetInterpreterGroupBody.

        传译组列表信息

        :return: The interpreter_groups of this RestSetInterpreterGroupBody.
        :rtype: list[:class:`huaweicloudsdkmeeting.v1.InterpreterGroupInfo`]
        """
        return self._interpreter_groups

    @interpreter_groups.setter
    def interpreter_groups(self, interpreter_groups):
        r"""Sets the interpreter_groups of this RestSetInterpreterGroupBody.

        传译组列表信息

        :param interpreter_groups: The interpreter_groups of this RestSetInterpreterGroupBody.
        :type interpreter_groups: list[:class:`huaweicloudsdkmeeting.v1.InterpreterGroupInfo`]
        """
        self._interpreter_groups = interpreter_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RestSetInterpreterGroupBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
